const system = require("../../../system");
const AppServiceBase = require("../../app.base");
const settings = require("../../../../config/settings");
const moment = require('moment');
//用户权限操作
class UtilsLogsService extends AppServiceBase {
  constructor() {
    super();
    this.esUtils = system.getObject("util.esUtils");
  }
  /**
     * 公司模糊查询
     * actionBody     
     * {
     *    indexName:索引名称,
     *    opTitle:标题－否,
     *    identifyCode:标识-否,
     *    messageBody:参数内容-否,
     *    errorInfo:错误信息－否,
     *    currentPage:第几页,
     *    pageSize:每页大小
     * }
     */
  async getListByIndexName(actionBody, req) {
    if (!actionBody.indexName) {
      return system.getResult(null, "indexName　can not be empty");
    }
    var pageSize = !actionBody.pageSize ? 20 : Number(actionBody.pageSize);
    if (pageSize < 0) {
      pageSize = 20;
    }
    if (pageSize > 200) {
      pageSize = 200;
    }
    var from = !actionBody.currentPage ? 0 : Number((actionBody.currentPage - 1) * pageSize);
    if (from < 0) {
      from = 0;
    }

    var esIndexName = actionBody.indexName + "/_search";
    var params = {
      "query": {
        "bool": {
          "must": []
        }
      },
      "from": from,
      "size": pageSize,
      "_source": [
        "opTitle",
        "identifyCode",
        "messageBody",
        "resultInfo",
        "errorInfo",
        "requestId",
        "created_at"
      ]
      ,
      "sort": [
        {
          "created_at": "desc"
        }
      ]
    }
    if (actionBody.opTitle) {
      // params.query.bool.must.push({
      //   "query_string": {
      //     "default_field": "opTitle",
      //     "query": '\"' + actionBody.opTitle + '\"'
      //   }
      // });
      params.query.bool.must.push({
        "wildcard": {
          "opTitle": "*" + actionBody.opTitle + "*"
        }
      });
    }
    if (actionBody.identifyCode) {
      params.query.bool.must.push({
        "wildcard": {
          "identifyCode": "*" + actionBody.identifyCode + "*"
        }
      });
    }
    if (actionBody.messageBody) {
      params.query.bool.must.push({
        "wildcard": {
          "messageBody": "*" + actionBody.messageBody + "*"
        }
      });
    }
    if (actionBody.errorInfo) {
      params.query.bool.must.push({
        "wildcard": {
          "errorInfo": "*" + actionBody.errorInfo + "*"
        }
      });
    }
    if (actionBody.requestId) {
      params.query.bool.must.push({
        "wildcard": {
          "requestId": "*" + actionBody.requestId + "*"
        }
      });
    }
    var resultData = null;
    try {
      resultData = await this.esUtils.execPostEs(settings.queuedName, params, esIndexName);
      var sources = [];
      var data = {
        "totalCount": 0,
        "pageSize": pageSize,
        "currentPage": from === 0 ? from : (from - 1),
        "list": sources
      };
      if (resultData.status != 1) {
        return system.getResult(null, resultData.message);
      }
      if (!resultData.data || !resultData.data.hits) {
        return system.getResult(null, "data is empty");
      }
      if (!resultData.data.hits.hits || resultData.data.hits.hits.length === 0) {
        return system.getResult(null, "data is empty!");
      }
      data.totalCount = typeof resultData.data.hits.total === "object" ? resultData.data.hits.total.value : resultData.data.hits.total;
      resultData.data.hits.hits.forEach(function (c) {
        var source = {
          "opTitle": c._source.opTitle,
          "identifyCode": c._source.identifyCode,
          "messageBody": c._source.messageBody,
          "resultInfo": c._source.resultInfo,
          "errorInfo": c._source.errorInfo,
          "requestId": c._source.requestId,
          "created_at": c._source.created_at
        };
        sources.push(source);
      });
      return system.getResultSuccess(data);
    } catch (error) {
      var stackStr = error.stack ? error.stack : JSON.stringify(error);
      console.log(stackStr, ".. getListByLikeCompanyName query is error");
      //TODO:日志
      return system.getResultError("query is error");
    }
  }

}
module.exports = UtilsLogsService;
